@@ -275,6 +275,7 @@ from .._impl import (
     scout_compute_api_ScatterSummarizationStrategyVisitor as ScatterSummarizationStrategyVisitor,
     scout_compute_api_SelectIndexFrom1dEnumArraySeries as SelectIndexFrom1dEnumArraySeries,
     scout_compute_api_SelectIndexFrom1dNumericArraySeries as SelectIndexFrom1dNumericArraySeries,
+    scout_compute_api_SelectNewestPointsSeries as SelectNewestPointsSeries,
     scout_compute_api_SelectValue as SelectValue,
     scout_compute_api_SelectValueVisitor as SelectValueVisitor,
     scout_compute_api_Series as Series,
@@ -615,6 +616,7 @@ __all__ = [
     'ScatterSummarizationStrategyVisitor',
     'SelectIndexFrom1dEnumArraySeries',
     'SelectIndexFrom1dNumericArraySeries',
+    'SelectNewestPointsSeries',
     'SelectValue',
     'SelectValueVisitor',
     'Series',
