@@ -120,6 +120,7 @@ from .._impl import (
     scout_compute_resolved_api_ScatterNode as ScatterNode,
     scout_compute_resolved_api_SelectIndexFromEnumArraySeriesNode as SelectIndexFromEnumArraySeriesNode,
     scout_compute_resolved_api_SelectIndexFromNumericArraySeriesNode as SelectIndexFromNumericArraySeriesNode,
+    scout_compute_resolved_api_SelectNewestPointsSeriesNode as SelectNewestPointsSeriesNode,
     scout_compute_resolved_api_SelectValueNode as SelectValueNode,
     scout_compute_resolved_api_SelectValueNodeVisitor as SelectValueNodeVisitor,
     scout_compute_resolved_api_SeriesCrossoverRangesNode as SeriesCrossoverRangesNode,
@@ -277,6 +278,7 @@ __all__ = [
     'ScatterNode',
     'SelectIndexFromEnumArraySeriesNode',
     'SelectIndexFromNumericArraySeriesNode',
+    'SelectNewestPointsSeriesNode',
     'SelectValueNode',
     'SelectValueNodeVisitor',
     'SeriesCrossoverRangesNode',
