@@ -15,5 +15,25 @@ from .._impl import (
     scout_template_api_TemplateMetadata as TemplateMetadata,
     scout_template_api_TemplateSummary as TemplateSummary,
     scout_template_api_UpdateMetadataRequest as UpdateMetadataRequest,
+    scout_template_api_UpdateRefNameRequest as UpdateRefNameRequest,
 )
 
+__all__ = [
+    'CommitTemplateRequest',
+    'CreateTemplateRequest',
+    'GetAllLabelsAndPropertiesResponse',
+    'MergeToMainRequest',
+    'SaveTemplateRequest',
+    'SearchTemplatesQuery',
+    'SearchTemplatesQueryVisitor',
+    'SearchTemplatesRequest',
+    'SearchTemplatesResponse',
+    'SortBy',
+    'SortByField',
+    'Template',
+    'TemplateMetadata',
+    'TemplateSummary',
+    'UpdateMetadataRequest',
+    'UpdateRefNameRequest',
+]
+
