@@ -11,7 +11,6 @@ from .._impl import (
     timeseries_logicalseries_api_BigQueryType as BigQueryType,
     timeseries_logicalseries_api_BucketName as BucketName,
     timeseries_logicalseries_api_ColumnName as ColumnName,
-    timeseries_logicalseries_api_Confidence as Confidence,
     timeseries_logicalseries_api_Context as Context,
     timeseries_logicalseries_api_ContextProperty as ContextProperty,
     timeseries_logicalseries_api_ContextPropertyVisitor as ContextPropertyVisitor,
@@ -21,8 +20,6 @@ from .._impl import (
     timeseries_logicalseries_api_DatabaseName as DatabaseName,
     timeseries_logicalseries_api_DatasetName as DatasetName,
     timeseries_logicalseries_api_FieldName as FieldName,
-    timeseries_logicalseries_api_GetSuggestedTagsRequest as GetSuggestedTagsRequest,
-    timeseries_logicalseries_api_GetSuggestedTagsResponse as GetSuggestedTagsResponse,
     timeseries_logicalseries_api_Influx1Locator as Influx1Locator,
     timeseries_logicalseries_api_Influx2Locator as Influx2Locator,
     timeseries_logicalseries_api_InfluxType as InfluxType,
@@ -52,3 +49,53 @@ from .._impl import (
     timeseries_logicalseries_api_VisualCrossingType as VisualCrossingType,
 )
 
+__all__ = [
+    'AttributeName',
+    'BatchCreateLogicalSeriesRequest',
+    'BatchCreateLogicalSeriesResponse',
+    'BatchResolveSeriesRequest',
+    'BatchResolveSeriesResponse',
+    'BatchUpdateLogicalSeriesRequest',
+    'BatchUpdateLogicalSeriesResponse',
+    'BigQueryLocator',
+    'BigQueryType',
+    'BucketName',
+    'ColumnName',
+    'Context',
+    'ContextProperty',
+    'ContextPropertyVisitor',
+    'CreateLogicalSeries',
+    'CsvLocator',
+    'CsvLocatorV2',
+    'DatabaseName',
+    'DatasetName',
+    'FieldName',
+    'Influx1Locator',
+    'Influx2Locator',
+    'InfluxType',
+    'LocationName',
+    'Locator',
+    'LocatorVisitor',
+    'LogicalSeries',
+    'MeasureName',
+    'MeasurementName',
+    'NominalLocator',
+    'ProjectName',
+    'ResolveSeriesError',
+    'ResolveSeriesRequest',
+    'ResolveSeriesResponse',
+    'ResolveSeriesResponseVisitor',
+    'SchemaName',
+    'TableName',
+    'TimescaleDbLocator',
+    'TimescaleType',
+    'TimestreamLocator',
+    'TimestreamType',
+    'UnitUpdate',
+    'UnitUpdateVisitor',
+    'UpdateLogicalSeries',
+    'VisualCrossingEndpointUri',
+    'VisualCrossingLocator',
+    'VisualCrossingType',
+]
+
